/*******************************
 
 Author : Sebastien Verel
 Date   : 2014/04/13
 
 Licence : LGPLv3
 
 
 
 *********************************/
import java.util.ArrayList;

public class Main {
	
	/***
	 *
	 *    Tests of data frame
	 *
	 ***/
	public static void testDataFrame() {
		// test of dataframe
		DataFrame data = new DataFrame("example.csv");
		
		System.out.println(" Data frame complet:");
		System.out.print(data);
		
		// test of select in dataframe
		System.out.println("\n Select:");
		System.out.print(data.select(0, "Sunny"));

		// Values of attributes
		System.out.println("\n Values of the attributes:");
		for(AttributeValues values : data.values) {
		    for(String value : values.getValues())
			System.out.print(value + " ");
		    System.out.print("\n");
		} 
		System.out.print("\n");
	}
	
	/***
	 *
	 *    Tests of prediction using Decision Tree
	 *
	 ***/
	public static void testPredict() {
		// dataframe
		DataFrame data = new DataFrame("example.csv");
		
		// A decision tree make "by hand"
		Node root = new Node(0, "Outlook", false); // 0 : Outlook = Sunny, Overcast, Rain
		root.add("Sunny", new Node(0, "Yes", true));
		Node novercast = new Node(3, "Wind", false); // 3 : Wind = Weak, Strong
		novercast.add("Weak", new Node(0, "Yes", true));
		novercast.add("Strong", new Node(1, "No", true));
		root.add("Overcast", novercast);
		root.add("Rain", new Node(1, "No", true));
		
		// Decision tree
		DecisionTree tree = new DecisionTree();
		tree.setRoot(root);
		
		System.out.println("Print the tree:");
		System.out.println(tree);
		
		// Prediction on the training set
		ArrayList<String> results = tree.predict(data);
		
		// print the result
		for(String r : results)
		    System.out.println(r);
	}
	
	/***
	 *
	 *    Tests of ID3
	 *
	 ***/
	public static void testID3() {
		// dataframe
		DataFrame data = new DataFrame("example.csv");
		
		DecisionTree tree = new DecisionTree();
		
		tree.learn(data, "Playball");
		
		System.out.println("Print the tree:");
		System.out.println(tree);
		
		// prediction of the training set
		ArrayList<String> results = tree.predict(data);
		
		// print the result
		int attId = data.getAttributeId("Playball");
		for(int i = 0; i < results.size(); i++) {
		    System.out.println(data.getExample(i).get(data, attId) + " " + results.get(i));
		}
	}
	
	/***
	 *
	 *    The Main
	 *
	 ***/
	public static void main(String[] args) {
		// test : remove when you have understood
		testDataFrame();
		
		// Where you have something to do
		testPredict();
		
		// Where you have something to do
		testID3();
	}
	
}
